@@ -1,19 +1,20 @@
 /* last-time.c: Part of GNU CSSC.
- * 
- *    Copyright (C) 1998, Free Software Foundation, Inc. 
- * 
- *    This program is free software: you can redistribute it and/or modify
- *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation, either version 3 of the License, or
- *    (at your option) any later version.
- *    
- *    This program is distributed in the hope that it will be useful,
- *    but WITHOUT ANY WARRANTY; without even the implied warranty of
- *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *    GNU General Public License for more details.
- *    
- *    You should have received a copy of the GNU General Public License
- *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2007,
+ * 2008, 2009, 2010, 2001, 2014, 2019 Free Software Foundation, Inc.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  *
  * This program is not installed as part of CSSC.  It's just desinged
@@ -23,19 +24,18 @@
  * No attempt has been made to make this program use the
  * Autoconf-generated configuration information.
  */
-
-
+#include <config.h>
 
 #include <stdio.h>
 #include <time.h>
 
 
-static int* 
+static int*
 next_field(struct tm *ptm,
 	   int *current)
 {
   int *next;
-  
+
   if (current == &ptm->tm_year)
     next = &ptm->tm_mon;
   else if (current == &ptm->tm_mon)
@@ -69,12 +69,12 @@ int main()
   tm_time.tm_min = 0;
   tm_time.tm_sec = 0;
   tm_time.tm_isdst = -1;
-  
+
   ptm = &tm_time;
   pfield = &ptm->tm_year;
 
   old_field_val = *pfield;
-  
+
   while (maxiters--)
     {
       now = mktime(ptm);
@@ -98,7 +98,7 @@ int main()
 	{
 	  then = now;
 	}
-      
+
       old_field_val = *pfield;
       ++*pfield;
     }
@@ -106,4 +106,3 @@ int main()
 	 " break very easily; is this a 64-bit system (or more)?\n");
   exit(0);			/* this can happen too. */
 }
-
